@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from django.core.exceptions import ObjectDoesNotExist
 from edc_fieldsets import FieldsetsModelAdminMixin
 from edc_visit_tracking.modeladmin_mixins import CrfModelAdminMixin
 
@@ -24,9 +25,11 @@ class ModelAdminCrfDashboardMixin(
 
     def get_changeform_initial_data(self, request) -> dict:
         initial_data = super().get_changeform_initial_data(request)
-        initial_data.update(
-            report_datetime=getattr(
-                self.related_visit(request), self.report_datetime_field_attr, None
-            ),
-        )
+        try:
+            related_visit = self.related_visit(request)
+        except ObjectDoesNotExist:
+            report_datetime = None
+        else:
+            report_datetime = getattr(related_visit, self.report_datetime_field_attr, None)
+        initial_data.update(report_datetime=report_datetime)
         return initial_data
